# file-size-package

English(US):

This simple Python package project was born from a curiosity to know the file size in each unit of measurement (B, KB, MB, GB, etc.). Futhermore, I was learning about how to create the Python package.

Português(BR):

Este simples projeto de pacote Python nasceu de uma curiosidade em saber o tamanho do arquivo em cada unidade de medida (B, KB, MB, GB, etc.). Além disso, eu estava aprendendo sobre como criar um pacote Python.

## Installation

Você pode instalar o pacote via pip:

```bash
pip install file-size
```

## Usage

```python
from file_size.size import file_size

file_size(file_path)
```

## Author
Kauã Fabricio

## License
[MIT](https://choosealicense.com/licenses/mit)

